--[[
**************************************************************************
*     Module de mesure des FPS de LockOn 3.00                            *
*     Par KaTZe     -         http://www.3rd-wing.net                    *
*     Version 3.0.0  du   01/09/2014                                     *
**************************************************************************
--]]


DEBUG_MODE = true; 	-- fichier export dans User\VotreCompte\Saved Games\DCS\Export

------------------------------------------------------------------------
--    Fonction Log													  --
------------------------------------------------------------------------
function log(message)
	if DEBUG_MODE and not fichierFPSLog then
       	fichierFPSLog = io.open(lfs.writedir().."Export\\KTZ-FpsCheck-"..os.date("%Y%m%d-%H%M")..".csv", "w");
		if fichierFPSLog then
			fichierFPSLog:write("**************************************************************************\n");
			fichierFPSLog:write("*     Fichier log du Fps-Check                                           *\n");
			fichierFPSLog:write("*     Par KaTZe  -  http://www.3rd-wing.net                              *\n");
			fichierFPSLog:write("*     Version 3.0.0 du 01/09/2014                                        *\n");
			fichierFPSLog:write("**************************************************************************\n\n");
		end
    end
	if fichierFPSLog then
        fichierFPSLog:write(string.format(" %s - %s",os.date("%d/%m/%y %H:%M:%S"),message),"\n");
	end
end


log("---KaTZe Log: KTZ-FPS-Check Activated ----")


-- Corps du programme d'export

StartTime = LoGetMissionStartTime()
CurrentTime = LoGetModelTime()
SamplingPeriod = 5
NextSampleTime = CurrentTime + SamplingPeriod
	
fps_counter = 0
fps_max = 0
fps_min = 0
fps_tot = 0
fps_0_10 = 0
fps_10_20 = 0
fps_20_30 = 0
fps_30_40 = 0
fps_40_50 = 0
fps_50 = 0
temps = CurrentTimes




KTZ_FPS =
{

-- Fonction au dmarrage mission
	K_Start=function(self)
		log("  ","\n")
		-- log("*** Fonction K_Start ***","\n")
		log(string.format(" Mission Start Time = %.0f",StartTime,"\n"))	
		log(string.format(" Sampling Period = %.0f secondes",NextSampleTime,"\n"))
		log("  ","\n")
	end,


-- Fonction  chaque image
	K_AfterNextFrame=function(self)
		fps_counter = fps_counter + 1
		CurrentTime = LoGetModelTime()
	end,

	
-- Fonction  chaque intervalle de temps
	K_AtInterval=function(self)
		fps_tot = fps_tot + fps_counter -- Compteur du total de frames
		
		-- log(string.format("*** Fonction K_AtInterval @= %.2f",CurrentTime,"\n"))
		-- Classement du nombre de frames de l'intervalle de temps dans l'histogramme
		if fps_counter < 10 * SamplingPeriod then
			fps_0_10 = fps_0_10 + fps_counter
		else
			if fps_counter < 20 * SamplingPeriod then
				fps_10_20 = fps_10_20 + fps_counter
			else
				if fps_counter < 30 * SamplingPeriod then
					fps_20_30 = fps_20_30 + fps_counter
				else
					if fps_counter < 40 * SamplingPeriod then
						fps_30_40 = fps_30_40 + fps_counter
					else
						if fps_counter < 50 * SamplingPeriod then
							fps_40_50 = fps_40_50 + fps_counter
						else
							fps_50 = fps_50 + fps_counter
						end
					end
				end	
			end
		end

		-- remise  zero du compteur de frame de l'intervalle de temps
		fps_counter = 0
		-- calcul de la date de fin du prochain intervalle de temps
		NextSampleTime = CurrentTime + SamplingPeriod
		
--		log(string.format("*** 10 < FPS < 20 = %.2f",fps_10_20,"\n"))
--		log(string.format("*** 20 < FPS < 30 = %.2f",fps_20_30,"\n"))
--		log(string.format("*** 30 < FPS < 40 = %.2f",fps_30_40,"\n"))
--		log(string.format("*** 40 < FPS < 50 = %.2f",fps_40_50,"\n"))
--		log(string.format("*** FPS < 50 = %.2f",fps_50,"\n"))
	end,

	
	
-- Fonction fin de mission
	K_Stop=function(self)
	
	-- log("*** Fonction K_Stop ***")
	log("  ","\n")
		

	-- Calcul des pourcentages de chaque tranche de l'histogramme
	local histo_0_10 = fps_0_10 / fps_tot * 100
	local histo_10_20 = fps_10_20 / fps_tot * 100
	local histo_20_30 = fps_20_30 / fps_tot * 100
	local histo_30_40 = fps_30_40 / fps_tot * 100
	local histo_40_50 = fps_40_50 / fps_tot * 100
	local histo_50 = fps_50 / fps_tot * 100
	

	-- log des rsultats
	log(string.format(" Total Number of Frames = %.0f",fps_tot,"\n"))
	log(string.format(" Flight Duration = %.0f secondes",CurrentTime,"\n"))
	log("  ","\n")
	log(string.format("*** Average FPS =  %.1f ",fps_tot/CurrentTime,"\n"))
	log("  ","\n")
	log(string.format("*** FPS < 10      = %.1f percent",histo_0_10,"\n"))
	log(string.format("*** 10 < FPS < 20 = %.1f percent",histo_10_20,"\n"))
	log(string.format("*** 20 < FPS < 30 = %.1f percent",histo_20_30,"\n"))
	log(string.format("*** 30 < FPS < 40 = %.1f percent",histo_30_40,"\n"))
	log(string.format("*** 40 < FPS < 50 = %.1f percent",histo_40_50,"\n"))
	log(string.format("*** 50 < FPS      = %.1f percent",histo_50,"\n"))
	log("  ","\n")
	log("Miaou  tous !!!")
		
	end,

}


-- Declencheur de squence (depuis export.lua)
------------------------------------------------------------------------
--    Squence : Dmarrage de mission (ExportStart)    			  --
------------------------------------------------------------------------

do
	local PrevLuaExportStart=LuaExportStart;

	LuaExportStart=function()
		KTZ_FPS:K_Start();
		
		if PrevLuaExportStart then
			PrevLuaExportStart();
		end
	end
end


------------------------------------------------------------------------
--    Squence : a chaque image            							  --
------------------------------------------------------------------------

do
	local PrevLuaExportAfterNextFrame=LuaExportAfterNextFrame;

	LuaExportAfterNextFrame=function()
		KTZ_FPS:K_AfterNextFrame();
			if CurrentTime >= NextSampleTime then
				KTZ_FPS:K_AtInterval();
			end
			
		if PrevLuaExportAfterNextFrame then
			PrevLuaExportAfterNextFrame();
		end
	end
end


------------------------------------------------------------------------
--    Squence : Fin de mission (ExportStop)         				  --
------------------------------------------------------------------------

do
	local PrevLuaExportStop=LuaExportStop;

	LuaExportStop=function()
		KTZ_FPS:K_Stop();

		if PrevLuaExportStop then
			PrevLuaExportStop();
		end
	end
end

